import http from './http';
import type { Product } from '@/types/Product';

/**
 * ดึงรายการ Product ทั้งหมดจาก backend
 */
export async function listProducts(): Promise<Product[]> {
  const { data } = await http.get('/products');
  return data;
}

/**
 * ดึงข้อมูล Product รายการเดียวโดยใช้ ProductID
 */
export async function getProduct(id: number): Promise<Product> {
  const { data } = await http.get(`/products/${id}`);
  return data;
}

/**
 * สร้าง Product ใหม่
 */
export async function createProduct(payload: Partial<Product>): Promise<Product> {
  const { data } = await http.post('/products', payload);
  return data;
}

/**
 * อัปเดต Product ที่มีอยู่
 */
export async function updateProduct(id: number, payload: Partial<Product>): Promise<Product> {
  const { data } = await http.patch(`/products/${id}`, payload);
  return data;
}

/**
 * ลบ Product ตาม ProductID
 */
export async function deleteProduct(id: number): Promise<void> {
  await http.delete(`/products/${id}`);
}
